@@ -26,9 +26,10 @@ try:
 except ImportError:
     from urlparse import urljoin
 
-from .exceptions import *
 import requests
 
+from .exceptions import (KeycloakConnectionError)
+
 
 class ConnectionManager(object):
     """ Represents a simple server connection.
